diff --git a/site/public/documentation/planet.md b/site/public/documentation/planet.md index 5bd7983..15e8a5b 100644 --- a/site/public/documentation/planet.md +++ b/site/public/documentation/planet.md @@ -34,7 +34,7 @@ planet.projection **`planet.path`** -`planet.path` is a [`d3.geo.path`](https://github.com/mbostock/d3/wiki/Geo-Paths) which uses the planet's internal projection to generate path data for geographical features. Its `context` method is commonly used by interal plugins to take a canvas context and return a path generator that can be used to draw on the globe. +`planet.path` is a [`d3.geo.path`](https://github.com/mbostock/d3/wiki/Geo-Paths) which uses the planet's internal projection to generate path data for geographical features. Its `context` method is commonly used by internal plugins to take a canvas context and return a path generator that can be used to draw on the globe.
<canvas id='quakeCanvas'></canvas>
<h1>Earthquakes: 2013</h1>
-<ul id='magnitues'></ul>
+<ul id='magnitudes'></ul>
<div id='controls'>
<div>
@@ -53,21 +53,21 @@
// Create a color scale for the various earthquake magnitudes; the
- // mininum magnitude in our data set is 2.5.
+ // minimum magnitude in our data set is 2.5.
var colors = d3.scale.pow()
.exponent(2)
.domain([2, 6,10])
.range(['rgb(255,255,204)', 'rgb(253,141,60)','rgb(128,0,38)'])
.clamp(true);
- // Also create a scale for mapping magnitues to ping angle sizes
+ // Also create a scale for mapping magnitudes to ping angle sizes
var angles = d3.scale.pow()
.exponent(2)
.domain([2.5, 10])
.range([0.5, 15])
.clamp(true);
- // Create a key to show the magnitues and their colors
- d3.select('#magnitues').selectAll('li')
+ // Create a key to show the magnitudes and their colors
+ d3.select('#magnitudes').selectAll('li')
.data(colors.ticks(9))
.enter()
.append('li')
diff --git a/site/public/examples/quake/_layout.ejs b/site/public/examples/quake/_layout.ejs
index 746af2b..f130f11 100644
--- a/site/public/examples/quake/_layout.ejs
+++ b/site/public/examples/quake/_layout.ejs
@@ -10,7 +10,7 @@
color: white;
}
- ul#magnitues {
+ ul#magnitudes {
position: absolute;
top: 100px;
left: 30px;
diff --git a/site/public/examples/quake/index.ejs b/site/public/examples/quake/index.ejs
index 5ce2575..9ad4eb6 100644
--- a/site/public/examples/quake/index.ejs
+++ b/site/public/examples/quake/index.ejs
@@ -1,6 +1,6 @@
Earthquakes: 2013
-
+
diff --git a/site/public/examples/rotating.ejs b/site/public/examples/rotating.ejs
index d4ce6a1..526833c 100644
--- a/site/public/examples/rotating.ejs
+++ b/site/public/examples/rotating.ejs
@@ -35,7 +35,7 @@
scaleExtent: [100, 300]
}));
globe.loadPlugin(planetaryjs.plugins.drag({
- // Dragging the globe shoud pause the
+ // Dragging the globe should pause the
// automatic rotation until we release the mouse.
onDragStart: function() {
globe.plugins.autorotate.pause();
diff --git a/site/public/examples/rotating.js b/site/public/examples/rotating.js
index abec7c4..bc89d8b 100644
--- a/site/public/examples/rotating.js
+++ b/site/public/examples/rotating.js
@@ -18,7 +18,7 @@
scaleExtent: [100, 300]
}));
globe.loadPlugin(planetaryjs.plugins.drag({
- // Dragging the globe shoud pause the
+ // Dragging the globe should pause the
// automatic rotation until we release the mouse.
onDragStart: function() {
globe.plugins.autorotate.pause();
diff --git a/site/public/js/homepage.js b/site/public/js/homepage.js
index b0a490f..159a112 100644
--- a/site/public/js/homepage.js
+++ b/site/public/js/homepage.js
@@ -18,7 +18,7 @@
scaleExtent: [100, 300]
}));
globe.loadPlugin(planetaryjs.plugins.drag({
- // Dragging the globe shoud pause the
+ // Dragging the globe should pause the
// automatic rotation until we release the mouse.
onDragStart: function() {
globe.plugins.autorotate.pause();
diff --git a/site/public/examples/quake/quake.js b/site/public/examples/quake/quake.js
index 7426c80..f4296d0 100644
--- a/site/public/examples/quake/quake.js
+++ b/site/public/examples/quake/quake.js
@@ -30,21 +30,21 @@
// Create a color scale for the various earthquake magnitudes; the
- // mininum magnitude in our data set is 2.5.
+ // minimum magnitude in our data set is 2.5.
var colors = d3.scale.pow()
.exponent(2)
.domain([2, 6,10])
.range(['rgb(255,255,204)', 'rgb(253,141,60)','rgb(128,0,38)'])
.clamp(true);
// Also create a scale for mapping magnitues to ping angle sizes
var angles = d3.scale.pow()
.exponent(2)
.domain([2.5, 10])
.range([0.5, 15])
.clamp(true);
- // Create a key to show the magnitues and their colors
- d3.select('#magnitues').selectAll('li')
+ // Create a key to show the magnitudes and their colors
+ d3.select('#magnitudes').selectAll('li')
.data(colors.ticks(9))
.enter()
.append('li')
@@ -30,21 +30,21 @@
.range(['rgb(255,255,204)', 'rgb(253,141,60)','rgb(128,0,38)'])
.clamp(true);
- // Also create a scale for mapping magnitues to ping angle sizes
+ // Also create a scale for mapping magnitudes to ping angle sizes
var angles = d3.scale.pow()
.exponent(2)